kernel: Update kernel 4.9 to 4.9.70

Runtime tested on lantiq.

Signed-off-by: Hauke Mehrtens <hauke@hauke-m.de>
This commit is contained in:
Hauke Mehrtens 2017-12-16 21:09:41 +01:00
parent e80ab48777
commit f704b643b9
31 changed files with 174 additions and 264 deletions

View File

@ -4,12 +4,12 @@ LINUX_RELEASE?=1
LINUX_VERSION-3.18 = .71
LINUX_VERSION-4.4 = .100
LINUX_VERSION-4.9 = .67
LINUX_VERSION-4.9 = .70
LINUX_VERSION-4.14 = .6
LINUX_KERNEL_HASH-3.18.71 = 5abc9778ad44ce02ed6c8ab52ece8a21c6d20d21f6ed8a19287b4a38a50c1240
LINUX_KERNEL_HASH-4.4.100 = 9936cd99c4bd35f6bc6962c9acdd1fa2ac8999e07a9be6a94a03b5492f1bd14f
LINUX_KERNEL_HASH-4.9.67 = 7fbaa7dcc17877dfa0c96fb9a7d2f4ffed20ceeb13cbbeb18d77213c6cf75f7d
LINUX_KERNEL_HASH-4.9.70 = baaf45f3826fa0d257a42005240cced402a12c99adf2a8d77402738304d5300a
LINUX_KERNEL_HASH-4.14.6 = 0907678ba9ea146ddbdecd0a0b6363f56b896b5c61c9a15e809effb3ea346ccc
ifdef KERNEL_PATCHVER

View File

@ -46,7 +46,7 @@
config ATH25
bool "Atheros AR231x/AR531x SoC support"
@@ -1002,6 +1002,7 @@ config MIPS_PARAVIRT
@@ -1004,6 +1004,7 @@ config MIPS_PARAVIRT
endchoice
source "arch/mips/alchemy/Kconfig"

View File

@ -1,6 +1,6 @@
--- a/drivers/spi/Kconfig
+++ b/drivers/spi/Kconfig
@@ -534,6 +534,12 @@ config SPI_QUP
@@ -533,6 +533,12 @@ config SPI_QUP
This driver can also be built as a module. If so, the module
will be called spi_qup.

View File

@ -1,6 +1,6 @@
--- a/drivers/spi/Kconfig
+++ b/drivers/spi/Kconfig
@@ -762,6 +762,13 @@ config SPI_TLE62X0
@@ -761,6 +761,13 @@ config SPI_TLE62X0
sysfs interface, with each line presented as a kind of GPIO
exposing both switch control and diagnostic feedback.

View File

@ -1,6 +1,6 @@
--- a/drivers/spi/Kconfig
+++ b/drivers/spi/Kconfig
@@ -769,6 +769,11 @@ config SPI_RB4XX_CPLD
@@ -768,6 +768,11 @@ config SPI_RB4XX_CPLD
SPI driver for the Xilinx CPLD chip present on the
MikroTik RB4xx boards.

View File

@ -696,7 +696,7 @@ Signed-off-by: Noralf Trønnes <noralf@tronnes.org>
}
--- a/drivers/usb/core/hub.c
+++ b/drivers/usb/core/hub.c
@@ -5045,7 +5045,7 @@ static void port_event(struct usb_hub *h
@@ -5054,7 +5054,7 @@ static void port_event(struct usb_hub *h
if (portchange & USB_PORT_STAT_C_OVERCURRENT) {
u16 status = 0, unused;

View File

@ -65,7 +65,7 @@ Signed-off-by: Phil Elwell <phil@raspberrypi.org>
+__copy_from_user_std(void *to, const void __user *from, unsigned long n);
+
static inline unsigned long __must_check
__copy_from_user(void *to, const void __user *from, unsigned long n)
__arch_copy_from_user(void *to, const void __user *from, unsigned long n)
{
--- a/arch/arm/lib/Makefile
+++ b/arch/arm/lib/Makefile

View File

@ -10,7 +10,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
--- a/Makefile
+++ b/Makefile
@@ -414,8 +414,8 @@ KERNELRELEASE = $(shell cat include/conf
@@ -409,8 +409,8 @@ KERNELRELEASE = $(shell cat include/conf
KERNELVERSION = $(VERSION)$(if $(PATCHLEVEL),.$(PATCHLEVEL)$(if $(SUBLEVEL),.$(SUBLEVEL)))$(EXTRAVERSION)
export VERSION PATCHLEVEL SUBLEVEL KERNELRELEASE KERNELVERSION

View File

@ -582,7 +582,7 @@ Signed-off-by: David S. Miller <davem@davemloft.net>
dnet_writel(bp, int_enable, INTR_ENB);
--- a/drivers/net/ethernet/emulex/benet/be_main.c
+++ b/drivers/net/ethernet/emulex/benet/be_main.c
@@ -3346,7 +3346,7 @@ int be_poll(struct napi_struct *napi, in
@@ -3344,7 +3344,7 @@ int be_poll(struct napi_struct *napi, in
be_process_mcc(adapter);
if (max_work < budget) {
@ -712,7 +712,7 @@ Signed-off-by: David S. Miller <davem@davemloft.net>
* then check once more to make sure we are done.
--- a/drivers/net/ethernet/ibm/ibmvnic.c
+++ b/drivers/net/ethernet/ibm/ibmvnic.c
@@ -999,7 +999,7 @@ restart_poll:
@@ -1009,7 +1009,7 @@ restart_poll:
if (frames_processed < budget) {
enable_scrq_irq(adapter, adapter->rx_scrq[scrq_num]);
@ -1095,7 +1095,7 @@ Signed-off-by: David S. Miller <davem@davemloft.net>
dma_intr_ena = smsc9420_reg_read(pd, DMAC_INTR_ENA);
--- a/drivers/net/ethernet/stmicro/stmmac/stmmac_main.c
+++ b/drivers/net/ethernet/stmicro/stmmac/stmmac_main.c
@@ -2677,7 +2677,7 @@ static int stmmac_poll(struct napi_struc
@@ -2678,7 +2678,7 @@ static int stmmac_poll(struct napi_struc
work_done = stmmac_rx(priv, budget);
if (work_done < budget) {

View File

@ -13,12 +13,12 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
--- a/Makefile
+++ b/Makefile
@@ -407,7 +407,7 @@ KBUILD_CFLAGS_KERNEL :=
KBUILD_AFLAGS := -D__ASSEMBLY__ $(call cc-option,-fno-PIE)
@@ -401,7 +401,7 @@ KBUILD_AFLAGS_KERNEL :=
KBUILD_CFLAGS_KERNEL :=
KBUILD_AFLAGS_MODULE := -DMODULE
KBUILD_CFLAGS_MODULE := -DMODULE
-KBUILD_LDFLAGS_MODULE := -T $(srctree)/scripts/module-common.lds
+KBUILD_LDFLAGS_MODULE = -T $(srctree)/scripts/module-common.lds $(if $(CONFIG_PROFILING),,-s)
GCC_PLUGINS_CFLAGS :=
# Read KERNELRELEASE from include/config/kernel.release (if it exists)
KERNELRELEASE = $(shell cat include/config/kernel.release 2> /dev/null)

View File

@ -15,7 +15,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
--- a/Makefile
+++ b/Makefile
@@ -1196,7 +1196,6 @@ all: modules
@@ -1197,7 +1197,6 @@ all: modules
PHONY += modules
modules: $(vmlinux-dirs) $(if $(KBUILD_BUILTIN),vmlinux) modules.builtin
@ -23,7 +23,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
@$(kecho) ' Building modules, stage 2.';
$(Q)$(MAKE) -f $(srctree)/scripts/Makefile.modpost
$(Q)$(MAKE) -f $(srctree)/scripts/Makefile.fwinst obj=firmware __fw_modbuild
@@ -1226,7 +1225,6 @@ _modinst_:
@@ -1227,7 +1226,6 @@ _modinst_:
rm -f $(MODLIB)/build ; \
ln -s $(CURDIR) $(MODLIB)/build ; \
fi

View File

@ -21,9 +21,9 @@ Signed-off-by: Gabor Juhos <juhosg@openwrt.org>
--- a/Makefile
+++ b/Makefile
@@ -409,6 +409,11 @@ KBUILD_AFLAGS_MODULE := -DMODULE
KBUILD_CFLAGS_MODULE := -DMODULE
@@ -404,6 +404,11 @@ KBUILD_CFLAGS_MODULE := -DMODULE
KBUILD_LDFLAGS_MODULE = -T $(srctree)/scripts/module-common.lds $(if $(CONFIG_PROFILING),,-s)
GCC_PLUGINS_CFLAGS :=
+ifdef CONFIG_LD_DEAD_CODE_DATA_ELIMINATION
+KBUILD_CFLAGS_KERNEL += $(call cc-option,-ffunction-sections,)
@ -33,7 +33,7 @@ Signed-off-by: Gabor Juhos <juhosg@openwrt.org>
# Read KERNELRELEASE from include/config/kernel.release (if it exists)
KERNELRELEASE = $(shell cat include/config/kernel.release 2> /dev/null)
KERNELVERSION = $(VERSION)$(if $(PATCHLEVEL),.$(PATCHLEVEL)$(if $(SUBLEVEL),.$(SUBLEVEL)))$(EXTRAVERSION)
@@ -633,11 +638,6 @@ KBUILD_CFLAGS += $(call cc-disable-warni
@@ -634,11 +639,6 @@ KBUILD_CFLAGS += $(call cc-disable-warni
KBUILD_CFLAGS += $(call cc-disable-warning, format-overflow)
KBUILD_CFLAGS += $(call cc-disable-warning, int-in-bool-context)

View File

@ -10,7 +10,7 @@ Signed-off-by: Gabor Juhos <juhosg@openwrt.org>
--- a/arch/mips/Kconfig
+++ b/arch/mips/Kconfig
@@ -1150,6 +1150,10 @@ config SYNC_R4K
@@ -1155,6 +1155,10 @@ config SYNC_R4K
config MIPS_MACHINE
def_bool n

View File

@ -16,7 +16,7 @@ Signed-off-by: Alexandros C. Couloumbis <alex@ozo.com>
--- a/arch/powerpc/Makefile
+++ b/arch/powerpc/Makefile
@@ -179,7 +179,6 @@ else
@@ -188,7 +188,6 @@ else
CHECKFLAGS += -D__LITTLE_ENDIAN__
endif

View File

@ -71,7 +71,7 @@ Signed-off-by: Tobias Wolf <dev-NTEO@vplace.de>
--- a/mm/page_alloc.c
+++ b/mm/page_alloc.c
@@ -5930,7 +5930,7 @@ static void __ref alloc_node_mem_map(str
@@ -5923,7 +5923,7 @@ static void __ref alloc_node_mem_map(str
mem_map = NODE_DATA(0)->node_mem_map;
#if defined(CONFIG_HAVE_MEMBLOCK_NODE_MAP) || defined(CONFIG_FLATMEM)
if (page_to_pfn(mem_map) != pgdat->node_start_pfn)

View File

@ -14,7 +14,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
--- a/Makefile
+++ b/Makefile
@@ -639,12 +639,12 @@ KBUILD_CFLAGS += $(call cc-option,-fdata
@@ -640,12 +640,12 @@ KBUILD_CFLAGS += $(call cc-option,-fdata
endif
ifdef CONFIG_CC_OPTIMIZE_FOR_SIZE

View File

@ -30,7 +30,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
#define PACKET_FANOUT_LB 1
--- a/net/packet/af_packet.c
+++ b/net/packet/af_packet.c
@@ -1780,6 +1780,7 @@ static int packet_rcv_spkt(struct sk_buf
@@ -1773,6 +1773,7 @@ static int packet_rcv_spkt(struct sk_buf
{
struct sock *sk;
struct sockaddr_pkt *spkt;
@ -38,7 +38,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
/*
* When we registered the protocol we saved the socket in the data
@@ -1787,6 +1788,7 @@ static int packet_rcv_spkt(struct sk_buf
@@ -1780,6 +1781,7 @@ static int packet_rcv_spkt(struct sk_buf
*/
sk = pt->af_packet_priv;
@ -46,7 +46,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
/*
* Yank back the headers [hope the device set this
@@ -1799,7 +1801,7 @@ static int packet_rcv_spkt(struct sk_buf
@@ -1792,7 +1794,7 @@ static int packet_rcv_spkt(struct sk_buf
* so that this procedure is noop.
*/
@ -55,7 +55,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
goto out;
if (!net_eq(dev_net(dev), sock_net(sk)))
@@ -2037,12 +2039,12 @@ static int packet_rcv(struct sk_buff *sk
@@ -2030,12 +2032,12 @@ static int packet_rcv(struct sk_buff *sk
unsigned int snaplen, res;
bool is_drop_n_account = false;
@ -71,7 +71,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
if (!net_eq(dev_net(dev), sock_net(sk)))
goto drop;
@@ -2168,12 +2170,12 @@ static int tpacket_rcv(struct sk_buff *s
@@ -2161,12 +2163,12 @@ static int tpacket_rcv(struct sk_buff *s
BUILD_BUG_ON(TPACKET_ALIGN(sizeof(*h.h2)) != 32);
BUILD_BUG_ON(TPACKET_ALIGN(sizeof(*h.h3)) != 48);
@ -87,7 +87,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
if (!net_eq(dev_net(dev), sock_net(sk)))
goto drop;
@@ -3252,6 +3254,7 @@ static int packet_create(struct net *net
@@ -3251,6 +3253,7 @@ static int packet_create(struct net *net
mutex_init(&po->pg_vec_lock);
po->rollover = NULL;
po->prot_hook.func = packet_rcv;
@ -95,7 +95,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
if (sock->type == SOCK_PACKET)
po->prot_hook.func = packet_rcv_spkt;
@@ -3838,6 +3841,16 @@ packet_setsockopt(struct socket *sock, i
@@ -3837,6 +3840,16 @@ packet_setsockopt(struct socket *sock, i
po->xmit = val ? packet_direct_xmit : dev_queue_xmit;
return 0;
}
@ -112,7 +112,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
default:
return -ENOPROTOOPT;
}
@@ -3891,6 +3904,13 @@ static int packet_getsockopt(struct sock
@@ -3889,6 +3902,13 @@ static int packet_getsockopt(struct sock
case PACKET_VNET_HDR:
val = po->has_vnet_hdr;
break;
@ -128,7 +128,7 @@ Signed-off-by: Felix Fietkau <nbd@nbd.name>
break;
--- a/net/packet/internal.h
+++ b/net/packet/internal.h
@@ -129,6 +129,7 @@ struct packet_sock {
@@ -128,6 +128,7 @@ struct packet_sock {
struct net_device __rcu *cached_dev;
int (*xmit)(struct sk_buff *skb);
struct packet_type prot_hook ____cacheline_aligned_in_smp;

View File

@ -105,7 +105,7 @@
case UPIO_AU:
p->serial_out(p, offset, value);
p->serial_in(p, UART_LCR); /* safe, no side-effects */
@@ -2756,6 +2776,7 @@ static int serial8250_request_std_resour
@@ -2759,6 +2779,7 @@ static int serial8250_request_std_resour
case UPIO_MEM32BE:
case UPIO_MEM16:
case UPIO_MEM:
@ -113,7 +113,7 @@
if (!port->mapbase)
break;
@@ -2794,6 +2815,7 @@ static void serial8250_release_std_resou
@@ -2797,6 +2818,7 @@ static void serial8250_release_std_resou
case UPIO_MEM32BE:
case UPIO_MEM16:
case UPIO_MEM:

View File

@ -65,7 +65,7 @@ Signed-off-by: Mark Brown <broonie@kernel.org>
+};
--- a/drivers/spi/Kconfig
+++ b/drivers/spi/Kconfig
@@ -404,6 +404,14 @@ config SPI_NUC900
@@ -403,6 +403,14 @@ config SPI_NUC900
help
SPI driver for Nuvoton NUC900 series ARM SoCs

View File

@ -1,6 +1,6 @@
--- a/arch/mips/Kconfig
+++ b/arch/mips/Kconfig
@@ -2311,6 +2311,12 @@ config MIPS_VPE_LOADER
@@ -2320,6 +2320,12 @@ config MIPS_VPE_LOADER
Includes a loader for loading an elf relocatable object
onto another VPE and running it.

View File

@ -24281,15 +24281,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
#endif /* CAAM_ERROR_H */
--- a/arch/mips/Kconfig
+++ b/arch/mips/Kconfig
@@ -617,6 +617,8 @@ config RALINK
@@ -619,6 +619,8 @@ config RALINK
select CLKDEV_LOOKUP
select ARCH_HAS_RESET_CONTROLLER
select RESET_CONTROLLER

View File

@ -14,7 +14,7 @@ Signed-off-by: John Crispin <blogic@openwrt.org>
--- a/arch/mips/Kconfig
+++ b/arch/mips/Kconfig
@@ -619,6 +619,9 @@ config RALINK
@@ -621,6 +621,9 @@ config RALINK
select RESET_CONTROLLER
select PINCTRL
select PINCTRL_RT2880

View File

@ -16,7 +16,7 @@ Acked-by: John Crispin <blogic@openwrt.org>
--- a/drivers/spi/Kconfig
+++ b/drivers/spi/Kconfig
@@ -534,6 +534,12 @@ config SPI_QUP
@@ -533,6 +533,12 @@ config SPI_QUP
This driver can also be built as a module. If so, the module
will be called spi_qup.

View File

@ -13,7 +13,7 @@ Signed-off-by: John Crispin <blogic@openwrt.org>
--- a/drivers/spi/Kconfig
+++ b/drivers/spi/Kconfig
@@ -540,6 +540,12 @@ config SPI_RT2880
@@ -539,6 +539,12 @@ config SPI_RT2880
help
This selects a driver for the Ralink RT288x/RT305x SPI Controller.

View File

@ -2464,7 +2464,7 @@
return ret;
}
}
@@ -1798,33 +1793,36 @@ static int stmmac_open(struct net_device
@@ -1799,33 +1794,36 @@ static int stmmac_open(struct net_device
ret = alloc_dma_desc_resources(priv);
if (ret < 0) {
@ -2508,7 +2508,7 @@
goto init_error;
}
@@ -1833,8 +1831,9 @@ static int stmmac_open(struct net_device
@@ -1834,8 +1832,9 @@ static int stmmac_open(struct net_device
ret = request_irq(priv->wol_irq, stmmac_interrupt,
IRQF_SHARED, dev->name, dev);
if (unlikely(ret < 0)) {
@ -2520,7 +2520,7 @@
goto wolirq_error;
}
}
@@ -1844,8 +1843,9 @@ static int stmmac_open(struct net_device
@@ -1845,8 +1844,9 @@ static int stmmac_open(struct net_device
ret = request_irq(priv->lpi_irq, stmmac_interrupt, IRQF_SHARED,
dev->name, dev);
if (unlikely(ret < 0)) {
@ -2532,7 +2532,7 @@
goto lpiirq_error;
}
}
@@ -1864,8 +1864,8 @@ wolirq_error:
@@ -1865,8 +1865,8 @@ wolirq_error:
init_error:
free_dma_desc_resources(priv);
dma_desc_error:
@ -2543,7 +2543,7 @@
return ret;
}
@@ -1884,10 +1884,9 @@ static int stmmac_release(struct net_dev
@@ -1885,10 +1885,9 @@ static int stmmac_release(struct net_dev
del_timer_sync(&priv->eee_ctrl_timer);
/* Stop and disconnect the PHY */
@ -2557,7 +2557,7 @@
}
netif_stop_queue(dev);
@@ -1947,13 +1946,13 @@ static void stmmac_tso_allocator(struct
@@ -1948,13 +1947,13 @@ static void stmmac_tso_allocator(struct
priv->cur_tx = STMMAC_GET_ENTRY(priv->cur_tx, DMA_TX_SIZE);
desc = priv->dma_tx + priv->cur_tx;
@ -2573,7 +2573,7 @@
0, 0);
tmp_len -= TSO_MAX_BUFF_SIZE;
@@ -1998,8 +1997,6 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -1999,8 +1998,6 @@ static netdev_tx_t stmmac_tso_xmit(struc
u8 proto_hdr_len;
int i;
@ -2582,7 +2582,7 @@
/* Compute header lengths */
proto_hdr_len = skb_transport_offset(skb) + tcp_hdrlen(skb);
@@ -2009,9 +2006,10 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2010,9 +2007,10 @@ static netdev_tx_t stmmac_tso_xmit(struc
if (!netif_queue_stopped(dev)) {
netif_stop_queue(dev);
/* This is a hard error, log it. */
@ -2595,7 +2595,7 @@
return NETDEV_TX_BUSY;
}
@@ -2049,11 +2047,11 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2050,11 +2048,11 @@ static netdev_tx_t stmmac_tso_xmit(struc
priv->tx_skbuff_dma[first_entry].len = skb_headlen(skb);
priv->tx_skbuff[first_entry] = skb;
@ -2609,7 +2609,7 @@
/* If needed take extra descriptors to fill the remaining payload */
tmp_pay_len = pay_len - TSO_MAX_BUFF_SIZE;
@@ -2082,8 +2080,8 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2083,8 +2081,8 @@ static netdev_tx_t stmmac_tso_xmit(struc
priv->cur_tx = STMMAC_GET_ENTRY(priv->cur_tx, DMA_TX_SIZE);
if (unlikely(stmmac_tx_avail(priv) <= (MAX_SKB_FRAGS + 1))) {
@ -2620,7 +2620,7 @@
netif_stop_queue(dev);
}
@@ -2127,7 +2125,7 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2128,7 +2126,7 @@ static netdev_tx_t stmmac_tso_xmit(struc
* descriptor and then barrier is needed to make sure that
* all is coherent before granting the DMA engine.
*/
@ -2629,7 +2629,7 @@
if (netif_msg_pktdata(priv)) {
pr_info("%s: curr=%d dirty=%d f=%d, e=%d, f_p=%p, nfrags %d\n",
@@ -2146,11 +2144,9 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2147,11 +2145,9 @@ static netdev_tx_t stmmac_tso_xmit(struc
priv->hw->dma->set_tx_tail_ptr(priv->ioaddr, priv->tx_tail_addr,
STMMAC_CHAN0);
@ -2641,7 +2641,7 @@
dev_err(priv->device, "Tx dma map failed\n");
dev_kfree_skb(skb);
priv->dev->stats.tx_dropped++;
@@ -2182,14 +2178,13 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2183,14 +2179,13 @@ static netdev_tx_t stmmac_xmit(struct sk
return stmmac_tso_xmit(skb, dev);
}
@ -2659,7 +2659,7 @@
}
return NETDEV_TX_BUSY;
}
@@ -2242,13 +2237,11 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2243,13 +2238,11 @@ static netdev_tx_t stmmac_xmit(struct sk
priv->tx_skbuff[entry] = NULL;
@ -2678,7 +2678,7 @@
priv->tx_skbuff_dma[entry].map_as_page = true;
priv->tx_skbuff_dma[entry].len = len;
@@ -2266,9 +2259,10 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2267,9 +2260,10 @@ static netdev_tx_t stmmac_xmit(struct sk
if (netif_msg_pktdata(priv)) {
void *tx_head;
@ -2692,7 +2692,7 @@
if (priv->extend_desc)
tx_head = (void *)priv->dma_etx;
@@ -2277,13 +2271,13 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2278,13 +2272,13 @@ static netdev_tx_t stmmac_xmit(struct sk
priv->hw->desc->display_ring(tx_head, DMA_TX_SIZE, false);
@ -2709,7 +2709,7 @@
netif_stop_queue(dev);
}
@@ -2319,13 +2313,11 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2320,13 +2314,11 @@ static netdev_tx_t stmmac_xmit(struct sk
if (dma_mapping_error(priv->device, des))
goto dma_map_err;
@ -2728,7 +2728,7 @@
priv->tx_skbuff_dma[first_entry].len = nopaged_len;
priv->tx_skbuff_dma[first_entry].last_segment = last_segment;
@@ -2346,7 +2338,7 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2347,7 +2339,7 @@ static netdev_tx_t stmmac_xmit(struct sk
* descriptor and then barrier is needed to make sure that
* all is coherent before granting the DMA engine.
*/
@ -2737,7 +2737,7 @@
}
netdev_sent_queue(dev, skb->len);
@@ -2357,12 +2349,10 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2358,12 +2350,10 @@ static netdev_tx_t stmmac_xmit(struct sk
priv->hw->dma->set_tx_tail_ptr(priv->ioaddr, priv->tx_tail_addr,
STMMAC_CHAN0);
@ -2751,7 +2751,7 @@
dev_kfree_skb(skb);
priv->dev->stats.tx_dropped++;
return NETDEV_TX_OK;
@@ -2433,16 +2423,16 @@ static inline void stmmac_rx_refill(stru
@@ -2434,16 +2424,16 @@ static inline void stmmac_rx_refill(stru
DMA_FROM_DEVICE);
if (dma_mapping_error(priv->device,
priv->rx_skbuff_dma[entry])) {
@ -2771,7 +2771,7 @@
}
if (priv->hw->mode->refill_desc3)
priv->hw->mode->refill_desc3(priv, p);
@@ -2450,17 +2440,17 @@ static inline void stmmac_rx_refill(stru
@@ -2451,17 +2441,17 @@ static inline void stmmac_rx_refill(stru
if (priv->rx_zeroc_thresh > 0)
priv->rx_zeroc_thresh--;
@ -2793,7 +2793,7 @@
entry = STMMAC_GET_ENTRY(entry, DMA_RX_SIZE);
}
@@ -2484,7 +2474,7 @@ static int stmmac_rx(struct stmmac_priv
@@ -2485,7 +2475,7 @@ static int stmmac_rx(struct stmmac_priv
if (netif_msg_rx_status(priv)) {
void *rx_head;
@ -2802,7 +2802,7 @@
if (priv->extend_desc)
rx_head = (void *)priv->dma_erx;
else
@@ -2546,9 +2536,9 @@ static int stmmac_rx(struct stmmac_priv
@@ -2547,9 +2537,9 @@ static int stmmac_rx(struct stmmac_priv
unsigned int des;
if (unlikely(priv->synopsys_id >= DWMAC_CORE_4_00))
@ -2814,7 +2814,7 @@
frame_len = priv->hw->desc->get_rx_frame_len(p, coe);
@@ -2557,9 +2547,9 @@ static int stmmac_rx(struct stmmac_priv
@@ -2558,9 +2548,9 @@ static int stmmac_rx(struct stmmac_priv
* ignored
*/
if (frame_len > priv->dma_buf_sz) {
@ -2827,7 +2827,7 @@
priv->dev->stats.rx_length_errors++;
break;
}
@@ -2571,11 +2561,11 @@ static int stmmac_rx(struct stmmac_priv
@@ -2572,11 +2562,11 @@ static int stmmac_rx(struct stmmac_priv
frame_len -= ETH_FCS_LEN;
if (netif_msg_rx_status(priv)) {
@ -2843,7 +2843,7 @@
}
/* The zero-copy is always used for all the sizes
@@ -2612,8 +2602,9 @@ static int stmmac_rx(struct stmmac_priv
@@ -2613,8 +2603,9 @@ static int stmmac_rx(struct stmmac_priv
} else {
skb = priv->rx_skbuff[entry];
if (unlikely(!skb)) {
@ -2855,7 +2855,7 @@
priv->dev->stats.rx_dropped++;
break;
}
@@ -2629,7 +2620,8 @@ static int stmmac_rx(struct stmmac_priv
@@ -2630,7 +2621,8 @@ static int stmmac_rx(struct stmmac_priv
}
if (netif_msg_pktdata(priv)) {
@ -2865,7 +2865,7 @@
print_pkt(skb->data, frame_len);
}
@@ -2732,7 +2724,7 @@ static int stmmac_change_mtu(struct net_
@@ -2733,7 +2725,7 @@ static int stmmac_change_mtu(struct net_
int max_mtu;
if (netif_running(dev)) {
@ -2874,7 +2874,7 @@
return -EBUSY;
}
@@ -2824,7 +2816,7 @@ static irqreturn_t stmmac_interrupt(int
@@ -2825,7 +2817,7 @@ static irqreturn_t stmmac_interrupt(int
pm_wakeup_event(priv->device, 0);
if (unlikely(!dev)) {
@ -2883,7 +2883,7 @@
return IRQ_NONE;
}
@@ -2882,7 +2874,6 @@ static void stmmac_poll_controller(struc
@@ -2883,7 +2875,6 @@ static void stmmac_poll_controller(struc
*/
static int stmmac_ioctl(struct net_device *dev, struct ifreq *rq, int cmd)
{
@ -2891,7 +2891,7 @@
int ret = -EOPNOTSUPP;
if (!netif_running(dev))
@@ -2892,9 +2883,9 @@ static int stmmac_ioctl(struct net_devic
@@ -2893,9 +2884,9 @@ static int stmmac_ioctl(struct net_devic
case SIOCGMIIPHY:
case SIOCGMIIREG:
case SIOCSMIIREG:
@ -2903,7 +2903,7 @@
break;
case SIOCSHWTSTAMP:
ret = stmmac_hwtstamp_ioctl(dev, rq);
@@ -2922,14 +2913,17 @@ static void sysfs_display_ring(void *hea
@@ -2923,14 +2914,17 @@ static void sysfs_display_ring(void *hea
x = *(u64 *) ep;
seq_printf(seq, "%d [0x%x]: 0x%x 0x%x 0x%x 0x%x\n",
i, (unsigned int)virt_to_phys(ep),
@ -2924,7 +2924,7 @@
p++;
}
seq_printf(seq, "\n");
@@ -2961,6 +2955,8 @@ static int stmmac_sysfs_ring_open(struct
@@ -2962,6 +2956,8 @@ static int stmmac_sysfs_ring_open(struct
return single_open(file, stmmac_sysfs_ring_read, inode->i_private);
}
@ -2933,7 +2933,7 @@
static const struct file_operations stmmac_rings_status_fops = {
.owner = THIS_MODULE,
.open = stmmac_sysfs_ring_open,
@@ -2983,11 +2979,11 @@ static int stmmac_sysfs_dma_cap_read(str
@@ -2984,11 +2980,11 @@ static int stmmac_sysfs_dma_cap_read(str
seq_printf(seq, "\tDMA HW features\n");
seq_printf(seq, "==============================\n");
@ -2948,7 +2948,7 @@
(priv->dma_cap.half_duplex) ? "Y" : "N");
seq_printf(seq, "\tHash Filter: %s\n",
(priv->dma_cap.hash_filter) ? "Y" : "N");
@@ -3005,9 +3001,9 @@ static int stmmac_sysfs_dma_cap_read(str
@@ -3006,9 +3002,9 @@ static int stmmac_sysfs_dma_cap_read(str
(priv->dma_cap.rmon) ? "Y" : "N");
seq_printf(seq, "\tIEEE 1588-2002 Time Stamp: %s\n",
(priv->dma_cap.time_stamp) ? "Y" : "N");
@ -2960,7 +2960,7 @@
(priv->dma_cap.eee) ? "Y" : "N");
seq_printf(seq, "\tAV features: %s\n", (priv->dma_cap.av) ? "Y" : "N");
seq_printf(seq, "\tChecksum Offload in TX: %s\n",
@@ -3054,8 +3050,7 @@ static int stmmac_init_fs(struct net_dev
@@ -3055,8 +3051,7 @@ static int stmmac_init_fs(struct net_dev
priv->dbgfs_dir = debugfs_create_dir(dev->name, stmmac_fs_dir);
if (!priv->dbgfs_dir || IS_ERR(priv->dbgfs_dir)) {
@ -2970,7 +2970,7 @@
return -ENOMEM;
}
@@ -3067,7 +3062,7 @@ static int stmmac_init_fs(struct net_dev
@@ -3068,7 +3063,7 @@ static int stmmac_init_fs(struct net_dev
&stmmac_rings_status_fops);
if (!priv->dbgfs_rings_status || IS_ERR(priv->dbgfs_rings_status)) {
@ -2979,7 +2979,7 @@
debugfs_remove_recursive(priv->dbgfs_dir);
return -ENOMEM;
@@ -3079,7 +3074,7 @@ static int stmmac_init_fs(struct net_dev
@@ -3080,7 +3075,7 @@ static int stmmac_init_fs(struct net_dev
dev, &stmmac_dma_cap_fops);
if (!priv->dbgfs_dma_cap || IS_ERR(priv->dbgfs_dma_cap)) {
@ -2988,7 +2988,7 @@
debugfs_remove_recursive(priv->dbgfs_dir);
return -ENOMEM;
@@ -3151,11 +3146,11 @@ static int stmmac_hw_init(struct stmmac_
@@ -3152,11 +3147,11 @@ static int stmmac_hw_init(struct stmmac_
} else {
if (chain_mode) {
priv->hw->mode = &chain_mode_ops;
@ -3002,7 +3002,7 @@
priv->mode = STMMAC_RING_MODE;
}
}
@@ -3163,7 +3158,7 @@ static int stmmac_hw_init(struct stmmac_
@@ -3164,7 +3159,7 @@ static int stmmac_hw_init(struct stmmac_
/* Get the HW capability (new GMAC newer than 3.50a) */
priv->hw_cap_support = stmmac_get_hw_features(priv);
if (priv->hw_cap_support) {
@ -3011,7 +3011,7 @@
/* We can override some gmac/dma configuration fields: e.g.
* enh_desc, tx_coe (e.g. that are passed through the
@@ -3188,8 +3183,9 @@ static int stmmac_hw_init(struct stmmac_
@@ -3189,8 +3184,9 @@ static int stmmac_hw_init(struct stmmac_
else if (priv->dma_cap.rx_coe_type1)
priv->plat->rx_coe = STMMAC_RX_COE_TYPE1;
@ -3023,7 +3023,7 @@
/* To use alternate (extended), normal or GMAC4 descriptor structures */
if (priv->synopsys_id >= DWMAC_CORE_4_00)
@@ -3199,20 +3195,20 @@ static int stmmac_hw_init(struct stmmac_
@@ -3200,20 +3196,20 @@ static int stmmac_hw_init(struct stmmac_
if (priv->plat->rx_coe) {
priv->hw->rx_csum = priv->plat->rx_coe;
@ -3049,7 +3049,7 @@
return 0;
}
@@ -3271,8 +3267,8 @@ int stmmac_dvr_probe(struct device *devi
@@ -3272,8 +3268,8 @@ int stmmac_dvr_probe(struct device *devi
priv->stmmac_clk = devm_clk_get(priv->device, STMMAC_RESOURCE_NAME);
if (IS_ERR(priv->stmmac_clk)) {
@ -3060,7 +3060,7 @@
/* If failed to obtain stmmac_clk and specific clk_csr value
* is NOT passed from the platform, probe fail.
*/
@@ -3321,7 +3317,7 @@ int stmmac_dvr_probe(struct device *devi
@@ -3322,7 +3318,7 @@ int stmmac_dvr_probe(struct device *devi
if ((priv->plat->tso_en) && (priv->dma_cap.tsoen)) {
ndev->hw_features |= NETIF_F_TSO;
priv->tso = true;
@ -3069,7 +3069,7 @@
}
ndev->features |= ndev->hw_features | NETIF_F_HIGHDMA;
ndev->watchdog_timeo = msecs_to_jiffies(watchdog);
@@ -3341,13 +3337,13 @@ int stmmac_dvr_probe(struct device *devi
@@ -3342,13 +3338,13 @@ int stmmac_dvr_probe(struct device *devi
*/
if ((priv->synopsys_id >= DWMAC_CORE_3_50) && (!priv->plat->riwt_off)) {
priv->use_riwt = 1;
@ -3085,7 +3085,7 @@
/* If a specific clk_csr value is passed from the platform
* this means that the CSR Clock Range selection cannot be
@@ -3368,15 +3364,17 @@ int stmmac_dvr_probe(struct device *devi
@@ -3369,15 +3365,17 @@ int stmmac_dvr_probe(struct device *devi
/* MDIO bus Registration */
ret = stmmac_mdio_register(ndev);
if (ret < 0) {
@ -3107,7 +3107,7 @@
goto error_netdev_register;
}
@@ -3387,7 +3385,7 @@ error_netdev_register:
@@ -3388,7 +3386,7 @@ error_netdev_register:
priv->hw->pcs != STMMAC_PCS_TBI &&
priv->hw->pcs != STMMAC_PCS_RTBI)
stmmac_mdio_unregister(ndev);
@ -3116,7 +3116,7 @@
netif_napi_del(&priv->napi);
error_hw_init:
clk_disable_unprepare(priv->pclk);
@@ -3411,7 +3409,7 @@ int stmmac_dvr_remove(struct device *dev
@@ -3412,7 +3410,7 @@ int stmmac_dvr_remove(struct device *dev
struct net_device *ndev = dev_get_drvdata(dev);
struct stmmac_priv *priv = netdev_priv(ndev);
@ -3125,7 +3125,7 @@
priv->hw->dma->stop_rx(priv->ioaddr);
priv->hw->dma->stop_tx(priv->ioaddr);
@@ -3449,8 +3447,8 @@ int stmmac_suspend(struct device *dev)
@@ -3450,8 +3448,8 @@ int stmmac_suspend(struct device *dev)
if (!ndev || !netif_running(ndev))
return 0;
@ -3136,7 +3136,7 @@
spin_lock_irqsave(&priv->lock, flags);
@@ -3544,8 +3542,8 @@ int stmmac_resume(struct device *dev)
@@ -3545,8 +3543,8 @@ int stmmac_resume(struct device *dev)
spin_unlock_irqrestore(&priv->lock, flags);

View File

@ -1718,7 +1718,7 @@
priv->tx_lpi_timer = STMMAC_DEFAULT_TWT_LS;
if ((priv->use_riwt) && (priv->hw->dma->rx_watchdog)) {
@@ -2519,7 +2517,7 @@ static int stmmac_rx(struct stmmac_priv
@@ -2520,7 +2518,7 @@ static int stmmac_rx(struct stmmac_priv
if (unlikely(status == discard_frame)) {
priv->dev->stats.rx_errors++;
if (priv->hwts_rx_en && !priv->extend_desc) {
@ -1727,7 +1727,7 @@
* with timestamp value, hence reinitialize
* them in stmmac_rx_refill() function so that
* device can reuse it.
@@ -2542,7 +2540,7 @@ static int stmmac_rx(struct stmmac_priv
@@ -2543,7 +2541,7 @@ static int stmmac_rx(struct stmmac_priv
frame_len = priv->hw->desc->get_rx_frame_len(p, coe);
@ -1736,7 +1736,7 @@
* (preallocated during init) then the packet is
* ignored
*/
@@ -2762,7 +2760,7 @@ static netdev_features_t stmmac_fix_feat
@@ -2763,7 +2761,7 @@ static netdev_features_t stmmac_fix_feat
/* Some GMAC devices have a bugged Jumbo frame support that
* needs to have the Tx COE disabled for oversized frames
* (due to limited buffer sizes). In this case we disable
@ -1745,7 +1745,7 @@
*/
if (priv->plat->bugged_jumbo && (dev->mtu > ETH_DATA_LEN))
features &= ~NETIF_F_CSUM_MASK;
@@ -2908,9 +2906,7 @@ static void sysfs_display_ring(void *hea
@@ -2909,9 +2907,7 @@ static void sysfs_display_ring(void *hea
struct dma_desc *p = (struct dma_desc *)head;
for (i = 0; i < size; i++) {
@ -1755,7 +1755,7 @@
seq_printf(seq, "%d [0x%x]: 0x%x 0x%x 0x%x 0x%x\n",
i, (unsigned int)virt_to_phys(ep),
le32_to_cpu(ep->basic.des0),
@@ -2919,7 +2915,6 @@ static void sysfs_display_ring(void *hea
@@ -2920,7 +2916,6 @@ static void sysfs_display_ring(void *hea
le32_to_cpu(ep->basic.des3));
ep++;
} else {
@ -1763,7 +1763,7 @@
seq_printf(seq, "%d [0x%x]: 0x%x 0x%x 0x%x 0x%x\n",
i, (unsigned int)virt_to_phys(ep),
le32_to_cpu(p->des0), le32_to_cpu(p->des1),
@@ -2989,7 +2984,7 @@ static int stmmac_sysfs_dma_cap_read(str
@@ -2990,7 +2985,7 @@ static int stmmac_sysfs_dma_cap_read(str
(priv->dma_cap.hash_filter) ? "Y" : "N");
seq_printf(seq, "\tMultiple MAC address registers: %s\n",
(priv->dma_cap.multi_addr) ? "Y" : "N");
@ -1772,7 +1772,7 @@
(priv->dma_cap.pcs) ? "Y" : "N");
seq_printf(seq, "\tSMA (MDIO) Interface: %s\n",
(priv->dma_cap.sma_mdio) ? "Y" : "N");
@@ -3265,44 +3260,8 @@ int stmmac_dvr_probe(struct device *devi
@@ -3266,44 +3261,8 @@ int stmmac_dvr_probe(struct device *devi
if ((phyaddr >= 0) && (phyaddr <= 31))
priv->plat->phy_addr = phyaddr;
@ -1819,7 +1819,7 @@
/* Init MAC and get the capabilities */
ret = stmmac_hw_init(priv);
@@ -3388,10 +3347,6 @@ error_netdev_register:
@@ -3389,10 +3348,6 @@ error_netdev_register:
error_mdio_register:
netif_napi_del(&priv->napi);
error_hw_init:
@ -1830,7 +1830,7 @@
free_netdev(ndev);
return ret;
@@ -3417,10 +3372,10 @@ int stmmac_dvr_remove(struct device *dev
@@ -3418,10 +3373,10 @@ int stmmac_dvr_remove(struct device *dev
stmmac_set_mac(priv->ioaddr, false);
netif_carrier_off(ndev);
unregister_netdev(ndev);
@ -1845,7 +1845,7 @@
if (priv->hw->pcs != STMMAC_PCS_RGMII &&
priv->hw->pcs != STMMAC_PCS_TBI &&
priv->hw->pcs != STMMAC_PCS_RTBI)
@@ -3469,14 +3424,14 @@ int stmmac_suspend(struct device *dev)
@@ -3470,14 +3425,14 @@ int stmmac_suspend(struct device *dev)
stmmac_set_mac(priv->ioaddr, false);
pinctrl_pm_select_sleep_state(priv->device);
/* Disable clock in case of PWM is off */
@ -1864,7 +1864,7 @@
return 0;
}
EXPORT_SYMBOL_GPL(stmmac_suspend);
@@ -3509,9 +3464,9 @@ int stmmac_resume(struct device *dev)
@@ -3510,9 +3465,9 @@ int stmmac_resume(struct device *dev)
priv->irq_wake = 0;
} else {
pinctrl_pm_select_default_state(priv->device);

View File

@ -4523,7 +4523,7 @@
/**
* stmmac_open - open entry point of the driver
* @dev : pointer to the device structure.
@@ -1821,7 +2598,7 @@ static int stmmac_open(struct net_device
@@ -1822,7 +2599,7 @@ static int stmmac_open(struct net_device
netdev_err(priv->dev,
"%s: ERROR: allocating the IRQ %d (error: %d)\n",
__func__, dev->irq, ret);
@ -4532,7 +4532,7 @@
}
/* Request the Wake IRQ in case of another line is used for WoL */
@@ -1848,8 +2625,8 @@ static int stmmac_open(struct net_device
@@ -1849,8 +2626,8 @@ static int stmmac_open(struct net_device
}
}
@ -4543,7 +4543,7 @@
return 0;
@@ -1858,7 +2635,12 @@ lpiirq_error:
@@ -1859,7 +2636,12 @@ lpiirq_error:
free_irq(priv->wol_irq, dev);
wolirq_error:
free_irq(dev->irq, dev);
@ -4556,7 +4556,7 @@
init_error:
free_dma_desc_resources(priv);
dma_desc_error:
@@ -1887,9 +2669,9 @@ static int stmmac_release(struct net_dev
@@ -1888,9 +2670,9 @@ static int stmmac_release(struct net_dev
phy_disconnect(dev->phydev);
}
@ -4568,7 +4568,7 @@
del_timer_sync(&priv->txtimer);
@@ -1901,14 +2683,13 @@ static int stmmac_release(struct net_dev
@@ -1902,14 +2684,13 @@ static int stmmac_release(struct net_dev
free_irq(priv->lpi_irq, dev);
/* Stop TX/RX DMA and clear the descriptors */
@ -4585,7 +4585,7 @@
netif_carrier_off(dev);
@@ -1927,22 +2708,24 @@ static int stmmac_release(struct net_dev
@@ -1928,22 +2709,24 @@ static int stmmac_release(struct net_dev
* @des: buffer start address
* @total_len: total length to fill in descriptors
* @last_segmant: condition for the last descriptor
@ -4614,7 +4614,7 @@
desc->des0 = cpu_to_le32(des + (total_len - tmp_len));
buff_size = tmp_len >= TSO_MAX_BUFF_SIZE ?
@@ -1950,7 +2733,7 @@ static void stmmac_tso_allocator(struct
@@ -1951,7 +2734,7 @@ static void stmmac_tso_allocator(struct
priv->hw->desc->prepare_tso_tx_desc(desc, 0, buff_size,
0, 1,
@ -4623,7 +4623,7 @@
0, 0);
tmp_len -= TSO_MAX_BUFF_SIZE;
@@ -1986,23 +2769,28 @@ static void stmmac_tso_allocator(struct
@@ -1987,23 +2770,28 @@ static void stmmac_tso_allocator(struct
*/
static netdev_tx_t stmmac_tso_xmit(struct sk_buff *skb, struct net_device *dev)
{
@ -4658,7 +4658,7 @@
/* This is a hard error, log it. */
netdev_err(priv->dev,
"%s: Tx Ring full when queue awake\n",
@@ -2017,10 +2805,10 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2018,10 +2806,10 @@ static netdev_tx_t stmmac_tso_xmit(struc
/* set new MSS value if needed */
if (mss != priv->mss) {
@ -4671,7 +4671,7 @@
}
if (netif_msg_tx_queued(priv)) {
@@ -2030,9 +2818,9 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2031,9 +2819,9 @@ static netdev_tx_t stmmac_tso_xmit(struc
skb->data_len);
}
@ -4683,7 +4683,7 @@
first = desc;
/* first descriptor: fill Headers on Buf1 */
@@ -2041,9 +2829,8 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2042,9 +2830,8 @@ static netdev_tx_t stmmac_tso_xmit(struc
if (dma_mapping_error(priv->device, des))
goto dma_map_err;
@ -4695,7 +4695,7 @@
first->des0 = cpu_to_le32(des);
@@ -2054,7 +2841,7 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2055,7 +2842,7 @@ static netdev_tx_t stmmac_tso_xmit(struc
/* If needed take extra descriptors to fill the remaining payload */
tmp_pay_len = pay_len - TSO_MAX_BUFF_SIZE;
@ -4704,7 +4704,7 @@
/* Prepare fragments */
for (i = 0; i < nfrags; i++) {
@@ -2063,24 +2850,34 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2064,24 +2851,34 @@ static netdev_tx_t stmmac_tso_xmit(struc
des = skb_frag_dma_map(priv->device, frag, 0,
skb_frag_size(frag),
DMA_TO_DEVICE);
@ -4748,7 +4748,7 @@
}
dev->stats.tx_bytes += skb->len;
@@ -2112,7 +2909,7 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2113,7 +2910,7 @@ static netdev_tx_t stmmac_tso_xmit(struc
priv->hw->desc->prepare_tso_tx_desc(first, 1,
proto_hdr_len,
pay_len,
@ -4757,7 +4757,7 @@
tcp_hdrlen(skb) / 4, (skb->len - proto_hdr_len));
/* If context desc is used to change MSS */
@@ -2127,20 +2924,20 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2128,20 +2925,20 @@ static netdev_tx_t stmmac_tso_xmit(struc
if (netif_msg_pktdata(priv)) {
pr_info("%s: curr=%d dirty=%d f=%d, e=%d, f_p=%p, nfrags %d\n",
@ -4784,7 +4784,7 @@
return NETDEV_TX_OK;
@@ -2164,21 +2961,27 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2165,21 +2962,27 @@ static netdev_tx_t stmmac_xmit(struct sk
struct stmmac_priv *priv = netdev_priv(dev);
unsigned int nopaged_len = skb_headlen(skb);
int i, csum_insertion = 0, is_jumbo = 0;
@ -4816,7 +4816,7 @@
/* This is a hard error, log it. */
netdev_err(priv->dev,
"%s: Tx Ring full when queue awake\n",
@@ -2190,20 +2993,18 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2191,20 +2994,18 @@ static netdev_tx_t stmmac_xmit(struct sk
if (priv->tx_path_in_lpi_mode)
stmmac_disable_eee_mode(priv);
@ -4840,7 +4840,7 @@
enh_desc = priv->plat->enh_desc;
/* To program the descriptors according to the size of the frame */
if (enh_desc)
@@ -2211,7 +3012,7 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2212,7 +3013,7 @@ static netdev_tx_t stmmac_xmit(struct sk
if (unlikely(is_jumbo) && likely(priv->synopsys_id <
DWMAC_CORE_4_00)) {
@ -4849,7 +4849,7 @@
if (unlikely(entry < 0))
goto dma_map_err;
}
@@ -2224,48 +3025,56 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2225,48 +3026,56 @@ static netdev_tx_t stmmac_xmit(struct sk
entry = STMMAC_GET_ENTRY(entry, DMA_TX_SIZE);
if (likely(priv->extend_desc))
@ -4919,7 +4919,7 @@
priv->hw->desc->display_ring(tx_head, DMA_TX_SIZE, false);
@@ -2273,10 +3082,10 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2274,10 +3083,10 @@ static netdev_tx_t stmmac_xmit(struct sk
print_pkt(skb->data, skb->len);
}
@ -4932,7 +4932,7 @@
}
dev->stats.tx_bytes += skb->len;
@@ -2311,14 +3120,14 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2312,14 +3121,14 @@ static netdev_tx_t stmmac_xmit(struct sk
if (dma_mapping_error(priv->device, des))
goto dma_map_err;
@ -4950,7 +4950,7 @@
if (unlikely((skb_shinfo(skb)->tx_flags & SKBTX_HW_TSTAMP) &&
priv->hwts_tx_en)) {
@@ -2330,7 +3139,7 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2331,7 +3140,7 @@ static netdev_tx_t stmmac_xmit(struct sk
/* Prepare the first descriptor setting the OWN bit too */
priv->hw->desc->prepare_tx_desc(first, 1, nopaged_len,
csum_insertion, priv->mode, 1,
@ -4959,7 +4959,7 @@
/* The own bit must be the latest setting done when prepare the
* descriptor and then barrier is needed to make sure that
@@ -2339,13 +3148,13 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2340,13 +3149,13 @@ static netdev_tx_t stmmac_xmit(struct sk
dma_wmb();
}
@ -4976,7 +4976,7 @@
return NETDEV_TX_OK;
@@ -2373,9 +3182,9 @@ static void stmmac_rx_vlan(struct net_de
@@ -2374,9 +3183,9 @@ static void stmmac_rx_vlan(struct net_de
}
@ -4988,7 +4988,7 @@
return 0;
return 1;
@@ -2384,30 +3193,33 @@ static inline int stmmac_rx_threshold_co
@@ -2385,30 +3194,33 @@ static inline int stmmac_rx_threshold_co
/**
* stmmac_rx_refill - refill used skb preallocated buffers
* @priv: driver private structure
@ -5029,7 +5029,7 @@
if (unlikely(net_ratelimit()))
dev_err(priv->device,
"fail to alloc skb entry %d\n",
@@ -2415,28 +3227,28 @@ static inline void stmmac_rx_refill(stru
@@ -2416,28 +3228,28 @@ static inline void stmmac_rx_refill(stru
break;
}
@ -5066,7 +5066,7 @@
netif_dbg(priv, rx_status, priv->dev,
"refill entry #%d\n", entry);
@@ -2452,31 +3264,33 @@ static inline void stmmac_rx_refill(stru
@@ -2453,31 +3265,33 @@ static inline void stmmac_rx_refill(stru
entry = STMMAC_GET_ENTRY(entry, DMA_RX_SIZE);
}
@ -5107,7 +5107,7 @@
priv->hw->desc->display_ring(rx_head, DMA_RX_SIZE, true);
}
@@ -2486,9 +3300,9 @@ static int stmmac_rx(struct stmmac_priv
@@ -2487,9 +3301,9 @@ static int stmmac_rx(struct stmmac_priv
struct dma_desc *np;
if (priv->extend_desc)
@ -5119,7 +5119,7 @@
/* read the status of the incoming frame */
status = priv->hw->desc->rx_status(&priv->dev->stats,
@@ -2499,20 +3313,20 @@ static int stmmac_rx(struct stmmac_priv
@@ -2500,20 +3314,20 @@ static int stmmac_rx(struct stmmac_priv
count++;
@ -5145,7 +5145,7 @@
entry);
if (unlikely(status == discard_frame)) {
priv->dev->stats.rx_errors++;
@@ -2522,9 +3336,9 @@ static int stmmac_rx(struct stmmac_priv
@@ -2523,9 +3337,9 @@ static int stmmac_rx(struct stmmac_priv
* them in stmmac_rx_refill() function so that
* device can reuse it.
*/
@ -5157,7 +5157,7 @@
priv->dma_buf_sz,
DMA_FROM_DEVICE);
}
@@ -2572,7 +3386,7 @@ static int stmmac_rx(struct stmmac_priv
@@ -2573,7 +3387,7 @@ static int stmmac_rx(struct stmmac_priv
*/
if (unlikely(!priv->plat->has_gmac4 &&
((frame_len < priv->rx_copybreak) ||
@ -5166,7 +5166,7 @@
skb = netdev_alloc_skb_ip_align(priv->dev,
frame_len);
if (unlikely(!skb)) {
@@ -2584,21 +3398,21 @@ static int stmmac_rx(struct stmmac_priv
@@ -2585,21 +3399,21 @@ static int stmmac_rx(struct stmmac_priv
}
dma_sync_single_for_cpu(priv->device,
@ -5192,7 +5192,7 @@
if (unlikely(!skb)) {
netdev_err(priv->dev,
"%s: Inconsistent Rx chain\n",
@@ -2607,12 +3421,12 @@ static int stmmac_rx(struct stmmac_priv
@@ -2608,12 +3422,12 @@ static int stmmac_rx(struct stmmac_priv
break;
}
prefetch(skb->data - NET_IP_ALIGN);
@ -5208,7 +5208,7 @@
priv->dma_buf_sz,
DMA_FROM_DEVICE);
}
@@ -2634,7 +3448,7 @@ static int stmmac_rx(struct stmmac_priv
@@ -2635,7 +3449,7 @@ static int stmmac_rx(struct stmmac_priv
else
skb->ip_summed = CHECKSUM_UNNECESSARY;
@ -5217,7 +5217,7 @@
priv->dev->stats.rx_packets++;
priv->dev->stats.rx_bytes += frame_len;
@@ -2642,7 +3456,7 @@ static int stmmac_rx(struct stmmac_priv
@@ -2643,7 +3457,7 @@ static int stmmac_rx(struct stmmac_priv
entry = next_entry;
}
@ -5226,7 +5226,7 @@
priv->xstats.rx_pkt_n += count;
@@ -2659,16 +3473,24 @@ static int stmmac_rx(struct stmmac_priv
@@ -2660,16 +3474,24 @@ static int stmmac_rx(struct stmmac_priv
*/
static int stmmac_poll(struct napi_struct *napi, int budget)
{
@ -5255,7 +5255,7 @@
}
return work_done;
}
@@ -2684,9 +3506,12 @@ static int stmmac_poll(struct napi_struc
@@ -2685,9 +3507,12 @@ static int stmmac_poll(struct napi_struc
static void stmmac_tx_timeout(struct net_device *dev)
{
struct stmmac_priv *priv = netdev_priv(dev);
@ -5269,7 +5269,7 @@
}
/**
@@ -2809,6 +3634,12 @@ static irqreturn_t stmmac_interrupt(int
@@ -2810,6 +3635,12 @@ static irqreturn_t stmmac_interrupt(int
{
struct net_device *dev = (struct net_device *)dev_id;
struct stmmac_priv *priv = netdev_priv(dev);
@ -5282,7 +5282,7 @@
if (priv->irq_wake)
pm_wakeup_event(priv->device, 0);
@@ -2822,16 +3653,30 @@ static irqreturn_t stmmac_interrupt(int
@@ -2823,16 +3654,30 @@ static irqreturn_t stmmac_interrupt(int
if ((priv->plat->has_gmac) || (priv->plat->has_gmac4)) {
int status = priv->hw->mac->host_irq_status(priv->hw,
&priv->xstats);
@ -5317,7 +5317,7 @@
}
/* PCS link status */
@@ -2916,7 +3761,7 @@ static void sysfs_display_ring(void *hea
@@ -2917,7 +3762,7 @@ static void sysfs_display_ring(void *hea
ep++;
} else {
seq_printf(seq, "%d [0x%x]: 0x%x 0x%x 0x%x 0x%x\n",
@ -5326,7 +5326,7 @@
le32_to_cpu(p->des0), le32_to_cpu(p->des1),
le32_to_cpu(p->des2), le32_to_cpu(p->des3));
p++;
@@ -2929,17 +3774,40 @@ static int stmmac_sysfs_ring_read(struct
@@ -2930,17 +3775,40 @@ static int stmmac_sysfs_ring_read(struct
{
struct net_device *dev = seq->private;
struct stmmac_priv *priv = netdev_priv(dev);
@ -5377,7 +5377,7 @@
}
return 0;
@@ -3222,11 +4090,14 @@ int stmmac_dvr_probe(struct device *devi
@@ -3223,11 +4091,14 @@ int stmmac_dvr_probe(struct device *devi
struct plat_stmmacenet_data *plat_dat,
struct stmmac_resources *res)
{
@ -5394,7 +5394,7 @@
if (!ndev)
return -ENOMEM;
@@ -3268,6 +4139,10 @@ int stmmac_dvr_probe(struct device *devi
@@ -3269,6 +4140,10 @@ int stmmac_dvr_probe(struct device *devi
if (ret)
goto error_hw_init;
@ -5405,7 +5405,7 @@
ndev->netdev_ops = &stmmac_netdev_ops;
ndev->hw_features = NETIF_F_SG | NETIF_F_IP_CSUM | NETIF_F_IPV6_CSUM |
@@ -3300,7 +4175,12 @@ int stmmac_dvr_probe(struct device *devi
@@ -3301,7 +4176,12 @@ int stmmac_dvr_probe(struct device *devi
"Enable RX Mitigation via HW Watchdog Timer\n");
}
@ -5419,7 +5419,7 @@
spin_lock_init(&priv->lock);
@@ -3345,7 +4225,11 @@ error_netdev_register:
@@ -3346,7 +4226,11 @@ error_netdev_register:
priv->hw->pcs != STMMAC_PCS_RTBI)
stmmac_mdio_unregister(ndev);
error_mdio_register:
@ -5432,7 +5432,7 @@
error_hw_init:
free_netdev(ndev);
@@ -3366,10 +4250,9 @@ int stmmac_dvr_remove(struct device *dev
@@ -3367,10 +4251,9 @@ int stmmac_dvr_remove(struct device *dev
netdev_info(priv->dev, "%s: removing driver", __func__);
@ -5445,7 +5445,7 @@
netif_carrier_off(ndev);
unregister_netdev(ndev);
if (priv->plat->stmmac_rst)
@@ -3408,20 +4291,19 @@ int stmmac_suspend(struct device *dev)
@@ -3409,20 +4292,19 @@ int stmmac_suspend(struct device *dev)
spin_lock_irqsave(&priv->lock, flags);
netif_device_detach(ndev);
@ -5470,7 +5470,7 @@
pinctrl_pm_select_sleep_state(priv->device);
/* Disable clock in case of PWM is off */
clk_disable(priv->plat->pclk);
@@ -3437,6 +4319,31 @@ int stmmac_suspend(struct device *dev)
@@ -3438,6 +4320,31 @@ int stmmac_suspend(struct device *dev)
EXPORT_SYMBOL_GPL(stmmac_suspend);
/**
@ -5502,7 +5502,7 @@
* stmmac_resume - resume callback
* @dev: device pointer
* Description: when resume this function is invoked to setup the DMA and CORE
@@ -3476,10 +4383,8 @@ int stmmac_resume(struct device *dev)
@@ -3477,10 +4384,8 @@ int stmmac_resume(struct device *dev)
spin_lock_irqsave(&priv->lock, flags);
@ -5515,7 +5515,7 @@
/* reset private mss value to force mss context settings at
* next tso xmit (only used for gmac4).
*/
@@ -3491,9 +4396,9 @@ int stmmac_resume(struct device *dev)
@@ -3492,9 +4397,9 @@ int stmmac_resume(struct device *dev)
stmmac_init_tx_coalesce(priv);
stmmac_set_rx_mode(ndev);

View File

@ -1491,7 +1491,7 @@
free_dma_tx_desc_resources(priv);
return ret;
@@ -2895,8 +2893,7 @@ static netdev_tx_t stmmac_tso_xmit(struc
@@ -2896,8 +2894,7 @@ static netdev_tx_t stmmac_tso_xmit(struc
priv->xstats.tx_set_ic_bit++;
}
@ -1501,7 +1501,7 @@
if (unlikely((skb_shinfo(skb)->tx_flags & SKBTX_HW_TSTAMP) &&
priv->hwts_tx_en)) {
@@ -2974,7 +2971,7 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -2975,7 +2972,7 @@ static netdev_tx_t stmmac_xmit(struct sk
/* Manage oversized TCP frames for GMAC4 device */
if (skb_is_gso(skb) && priv->tso) {
@ -1510,7 +1510,7 @@
return stmmac_tso_xmit(skb, dev);
}
@@ -3105,8 +3102,7 @@ static netdev_tx_t stmmac_xmit(struct sk
@@ -3106,8 +3103,7 @@ static netdev_tx_t stmmac_xmit(struct sk
priv->xstats.tx_set_ic_bit++;
}
@ -1520,7 +1520,7 @@
/* Ready to fill the first descriptor and set the OWN bit w/o any
* problems because all the descriptors are actually ready to be
@@ -3983,7 +3979,9 @@ static int stmmac_hw_init(struct stmmac_
@@ -3984,7 +3980,9 @@ static int stmmac_hw_init(struct stmmac_
struct mac_device_info *mac;
/* Identify the MAC HW device */
@ -1531,7 +1531,7 @@
priv->dev->priv_flags |= IFF_UNICAST_FLT;
mac = dwmac1000_setup(priv->ioaddr,
priv->plat->multicast_filter_bins,
@@ -4003,6 +4001,10 @@ static int stmmac_hw_init(struct stmmac_
@@ -4004,6 +4002,10 @@ static int stmmac_hw_init(struct stmmac_
priv->hw = mac;
@ -1542,7 +1542,7 @@
/* To use the chained or ring mode */
if (priv->synopsys_id >= DWMAC_CORE_4_00) {
priv->hw->mode = &dwmac4_ring_mode_ops;
@@ -4131,8 +4133,15 @@ int stmmac_dvr_probe(struct device *devi
@@ -4132,8 +4134,15 @@ int stmmac_dvr_probe(struct device *devi
if ((phyaddr >= 0) && (phyaddr <= 31))
priv->plat->phy_addr = phyaddr;
@ -1559,7 +1559,7 @@
/* Init MAC and get the capabilities */
ret = stmmac_hw_init(priv);
@@ -4149,7 +4158,7 @@ int stmmac_dvr_probe(struct device *devi
@@ -4150,7 +4159,7 @@ int stmmac_dvr_probe(struct device *devi
NETIF_F_RXCSUM;
if ((priv->plat->tso_en) && (priv->dma_cap.tsoen)) {
@ -1568,7 +1568,7 @@
priv->tso = true;
dev_info(priv->device, "TSO feature enabled\n");
}
@@ -4311,7 +4320,7 @@ int stmmac_suspend(struct device *dev)
@@ -4312,7 +4321,7 @@ int stmmac_suspend(struct device *dev)
}
spin_unlock_irqrestore(&priv->lock, flags);
--- a/drivers/crypto/caam/intern.h
+++ b/drivers/crypto/caam/intern.h
@@ -41,6 +41,7 @@ struct caam_drv_private_jr {
struct device *dev;
int ridx;
struct caam_job_ring __iomem *rregs; /* JobR's register space */
+ struct tasklet_struct irqtask;
int irq; /* One per queue */
/* Number of scatterlist crypt transforms active on the JobR */
@@ -63,10 +64,9 @@ struct caam_drv_private_jr {
@@ -64,10 +64,9 @@ struct caam_drv_private_jr {
* Driver-private storage for a single CAAM block instance
*/
struct caam_drv_private {
@ -24303,7 +24295,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
/* Physical-presence section */
struct caam_ctrl __iomem *ctrl; /* controller region */
@@ -102,11 +102,6 @@ struct caam_drv_private {
@@ -103,11 +102,6 @@ struct caam_drv_private {
#ifdef CONFIG_DEBUG_FS
struct dentry *dfs_root;
struct dentry *ctl; /* controller dir */
@ -24315,7 +24307,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
struct debugfs_blob_wrapper ctl_kek_wrap, ctl_tkek_wrap, ctl_tdsk_wrap;
struct dentry *ctl_kek, *ctl_tkek, *ctl_tdsk;
#endif
@@ -114,4 +109,22 @@ struct caam_drv_private {
@@ -115,4 +109,22 @@ struct caam_drv_private {
void caam_jr_algapi_init(struct device *dev);
void caam_jr_algapi_remove(struct device *dev);
@ -24363,16 +24355,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
static int caam_reset_hw_jr(struct device *dev)
{
struct caam_drv_private_jr *jrp = dev_get_drvdata(dev);
@@ -73,6 +82,8 @@ static int caam_jr_shutdown(struct devic
ret = caam_reset_hw_jr(dev);
+ tasklet_kill(&jrp->irqtask);
+
/* Release interrupt */
free_irq(jrp->irq, dev);
@@ -116,6 +127,8 @@ static int caam_jr_remove(struct platfor
@@ -118,6 +127,8 @@ static int caam_jr_remove(struct platfor
dev_err(jrdev, "Failed to shut down job ring\n");
irq_dispose_mapping(jrpriv->irq);
@ -24381,47 +24364,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
return ret;
}
@@ -128,7 +141,7 @@ static irqreturn_t caam_jr_interrupt(int
/*
* Check the output ring for ready responses, kick
* the threaded irq if jobs done.
*/
irqstate = rd_reg32(&jrp->rregs->jrintstatus);
if (!irqstate)
@@ -150,13 +163,18 @@ static irqreturn_t caam_jr_interrupt(int
/* Have valid interrupt at this point, just ACK and trigger */
wr_reg32(&jrp->rregs->jrintstatus, irqstate);
- return IRQ_WAKE_THREAD;
+ preempt_disable();
+ tasklet_schedule(&jrp->irqtask);
+ preempt_enable();
+
+ return IRQ_HANDLED;
}
-static irqreturn_t caam_jr_threadirq(int irq, void *st_dev)
+/* Deferred service handler, run as interrupt-fired tasklet */
+static void caam_jr_dequeue(unsigned long devarg)
{
int hw_idx, sw_idx, i, head, tail;
- struct device *dev = st_dev;
+ struct device *dev = (struct device *)devarg;
struct caam_drv_private_jr *jrp = dev_get_drvdata(dev);
void (*usercall)(struct device *dev, u32 *desc, u32 status, void *arg);
u32 *userdesc, userstatus;
@@ -230,8 +248,6 @@ static irqreturn_t caam_jr_threadirq(int
/* reenable / unmask IRQs */
clrsetbits_32(&jrp->rregs->rconfig_lo, JRCFG_IMSK, 0);
-
- return IRQ_HANDLED;
}
/**
@@ -275,6 +291,36 @@ struct device *caam_jr_alloc(void)
@@ -280,6 +291,36 @@ struct device *caam_jr_alloc(void)
EXPORT_SYMBOL(caam_jr_alloc);
/**
@ -24458,30 +24401,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
* caam_jr_free() - Free the Job Ring
* @rdev - points to the dev that identifies the Job ring to
* be released.
@@ -389,10 +435,11 @@ static int caam_jr_init(struct device *d
jrp = dev_get_drvdata(dev);
+ tasklet_init(&jrp->irqtask, caam_jr_dequeue, (unsigned long)dev);
+
/* Connect job ring interrupt handler. */
- error = request_threaded_irq(jrp->irq, caam_jr_interrupt,
- caam_jr_threadirq, IRQF_SHARED,
- dev_name(dev), dev);
+ error = request_irq(jrp->irq, caam_jr_interrupt, IRQF_SHARED,
+ dev_name(dev), dev);
if (error) {
dev_err(dev, "can't connect JobR %d interrupt (%d)\n",
jrp->ridx, jrp->irq);
@@ -454,6 +501,7 @@ out_free_inpring:
out_free_irq:
free_irq(jrp->irq, dev);
out_kill_deq:
+ tasklet_kill(&jrp->irqtask);
return error;
}
@@ -489,15 +537,28 @@ static int caam_jr_probe(struct platform
@@ -496,15 +537,28 @@ static int caam_jr_probe(struct platform
return -ENOMEM;
}
@ -24517,7 +24437,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
/* Identify the interrupt */
jrpriv->irq = irq_of_parse_and_map(nprop, 0);
@@ -517,10 +578,12 @@ static int caam_jr_probe(struct platform
@@ -524,10 +578,12 @@ static int caam_jr_probe(struct platform
atomic_set(&jrpriv->tfm_count, 0);

View File

@ -27,10 +27,10 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
+ disable_irq(fsl_dev->irq);
+
clk_disable_unprepare(fsl_dev->pix_clk);
clk_disable_unprepare(fsl_dev->clk);
@@ -263,6 +264,14 @@ static int fsl_dcu_drm_pm_resume(struct
return 0;
@@ -262,6 +263,12 @@ static int fsl_dcu_drm_pm_resume(struct
return ret;
}
@ -39,21 +39,11 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
+ dev_err(dev, "failed to enable dcu pix clk\n");
+ return ret;
+ }
+
+ enable_irq(fsl_dev->irq);
+
if (fsl_dev->tcon)
fsl_tcon_bypass_enable(fsl_dev->tcon);
fsl_dcu_drm_init_planes(fsl_dev->drm);
@@ -273,7 +282,6 @@ static int fsl_dcu_drm_pm_resume(struct
console_unlock();
drm_kms_helper_poll_enable(fsl_dev->drm);
- enable_irq(fsl_dev->irq);
return 0;
}
@@ -389,6 +397,12 @@ static int fsl_dcu_drm_probe(struct plat
@@ -388,6 +395,12 @@ static int fsl_dcu_drm_probe(struct plat
goto disable_clk;
}

View File

@ -995,7 +995,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
};
struct dmar_atsr_unit {
@@ -4250,27 +4251,40 @@ static inline void init_iommu_pm_ops(voi
@@ -4252,27 +4253,40 @@ static inline void init_iommu_pm_ops(voi
int __init dmar_parse_one_rmrr(struct acpi_dmar_header *header, void *arg)
{
struct acpi_dmar_reserved_memory *rmrr;
@ -1041,7 +1041,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
}
static struct dmar_atsr_unit *dmar_find_atsr(struct acpi_dmar_atsr *atsr)
@@ -4484,6 +4498,7 @@ static void intel_iommu_free_dmars(void)
@@ -4486,6 +4500,7 @@ static void intel_iommu_free_dmars(void)
list_for_each_entry_safe(rmrru, rmrr_n, &dmar_rmrr_units, list) {
list_del(&rmrru->list);
dmar_free_dev_scope(&rmrru->devices, &rmrru->devices_cnt);
@ -1049,7 +1049,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
kfree(rmrru);
}
@@ -5219,6 +5234,45 @@ static void intel_iommu_remove_device(st
@@ -5221,6 +5236,45 @@ static void intel_iommu_remove_device(st
iommu_device_unlink(iommu->iommu_dev, dev);
}
@ -1095,7 +1095,7 @@ Signed-off-by: Yangbo Lu <yangbo.lu@nxp.com>
#ifdef CONFIG_INTEL_IOMMU_SVM
#define MAX_NR_PASID_BITS (20)
static inline unsigned long intel_iommu_get_pts(struct intel_iommu *iommu)
@@ -5349,19 +5403,21 @@ struct intel_iommu *intel_svm_device_to_
@@ -5351,19 +5405,21 @@ struct intel_iommu *intel_svm_device_to_
#endif /* CONFIG_INTEL_IOMMU_SVM */
static const struct iommu_ops intel_iommu_ops = {

View File

@ -14,7 +14,7 @@ Signed-off-by: John Crispin <blogic@openwrt.org>
@@ -128,7 +141,7 @@ static irqreturn_t caam_jr_interrupt(int
/*
* Check the output ring for ready responses, kick
- * the threaded irq if jobs done.
+ * tasklet if jobs done.
*/
irqstate = rd_reg32(&jrp->rregs->jrintstatus);